%define _disable_ld_no_undefined 1

%define major		%{ver}.%{subver}
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define ver	2.8
%define subver	104

Name:		gsoap
Version:	%{ver}.%{subver}
Release:	%mkrel 5
Summary:	Development toolkit for SOAP/XML Web services in C/C++
Group:		System/Libraries
License:	GPLv2
URL:		https://www.cs.fsu.edu/~engelen/soap.html
Source:		https://downloads.sourceforge.net/gsoap2/gsoap_%{version}.zip
Source1:	soapcpp2.1
Source2:	wsdl2h.1

Patch0:		%{name}-libtool.patch
# Backport from gsoap 2.8.105
# Included so that the following security fix applies cleanly
Patch2:		gsoap-wsse.patch
# Backport from gsoap 2.8.109
# Fixes CVE: CVE-2020-13574 CVE-2020-13575 CVE-2020-13577 CVE-2020-13578
Patch3:		gsoap-plugins-hardening.patch
# Backport from gsoap 2.8.111
# Fixes CVE: CVE-2020-13576
Patch4:		gsoap-url-parse-hardening.patch

BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	libstdc++-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	flex

%description
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

%package -n	%{libname}
Summary:	Development toolkit for SOAP/XML Web services in C/C++
Group:		System/Libraries

Obsoletes:	%{_lib}gsoap2 < 2.8.93-5

%description -n	%{libname}
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

%package -n	%{develname}
Summary:	Devel libraries and headers for linking with gSOAP generated stubs
Group:		Development/C
Requires:	%{libname} = %version-%release
Provides:	%{name} = %version-%release
Provides:	%{name}-devel = %version-%release
Obsoletes:	%{name} < %version-%release

%description -n	%{develname}
gSOAP libraries, headers and generators for linking with and creating
gSOAP generated stubs.
 
%package	source
Summary:	Source files of %{name}
Group:		Development/C

%description	source
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

This package contains the source code.

%package	doc
Summary:	Documentation files of %{name}
Group:		Documentation

%description	doc
The gSOAP Web services development toolkit offers an XML to C/C++ language
binding to ease the development of SOAP/XML Web services in C and C/C++.

This package contains the documentation.

%prep
%setup -q -n %{name}-%{ver}
# keep a copy of source code (used by some TPM tools for Intel Classmate)
rm -rf %{name}-source
cp -a . ../%{name}-source
mv ../%{name}-source .

# remove pre-built binaries and libraries in source tree
rm -rf gsoap/bin
%patch -P 0 -p1 -b .soname
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1

# XML files non-executable
find gsoap/samples/autotest/databinding/examples -name '*.xml' \
    -exec chmod a-x {} ';'

# Documentation fonts non-executable
chmod a-x gsoap/doc/fonts/*

# make automake more happy
sed -i -e 's,\(^AM_INIT_AUTOMAKE(\[\),\1subdir-objects ,' configure.ac

# Remove stuff with gsoap license only - not GPL
rm -rf gsoap/extras gsoap/mod_gsoap gsoap/Symbian
sed 's!$(top_srcdir)/gsoap/extras/\*!!' -i gsoap/Makefile.am
rm -rf gsoap/doc/apache gsoap/doc/wininet gsoap/doc/isapi

# Remove pre-compiled binaries
rm -rf gsoap/bin
#rm gsoap/samples/calc_vs2005/calc_vs2005/soapcpp2.exe
rm gsoap/samples/rest/person
rm gsoap/samples/wcf/Basic/TransportSecurity/calculator
rm gsoap/VisualStudio2005/wsdl2h/wsdl2h/soapcpp2.exe

# Remove pre-generated files
rm gsoap/samples/webserver/opt{C.c,H.h,Stub.h}

# Remove .DS_Store files
find . -name .DS_Store -exec rm {} ';'

%build
export YACC='bison -y'
autoreconf -vfi
%configure --disable-static --prefix=/usr --enable-ipv6 --enable-samples

# Dependencies are not declared properly
%__make

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -R %{name}/import %{buildroot}%{_datadir}/%{name}
cp -R %{name}/WS %{buildroot}%{_datadir}/%{name}
cp -R %{name}/uddi2 %{buildroot}%{_datadir}/%{name}
cp %{name}/stdsoap2.cpp %{buildroot}%{_datadir}/%{name}
cp %{name}/stdsoap2.c %{buildroot}%{_datadir}/%{name}

%make_install

install -d %{buildroot}%{_prefix}/src/
rm -f %{buildroot}%{_libdir}/*.la

cp -a %{name}-source %{buildroot}%{_prefix}/src/%{name}

mkdir -p %{buildroot}%{_mandir}/man1
install -m 644 -p %{SOURCE1} %{SOURCE2} %{buildroot}%{_mandir}/man1

%check
make check

%files -n %{libname}
%license LICENSE.txt
%{_libdir}/libgsoap-*.so
%{_libdir}/libgsoap++-*.so
%{_libdir}/libgsoapck-*.so
%{_libdir}/libgsoapck++-*.so
%{_libdir}/libgsoapssl-*.so
%{_libdir}/libgsoapssl++-*.so

%files -n %{develname}
%{_bindir}/soapcpp2
%{_bindir}/wsdl2h
%{_includedir}/stdsoap2.h
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_mandir}/man1/soapcpp2.1*
%{_mandir}/man1/wsdl2h.1*
%{_libdir}/libgsoap.so
%{_libdir}/libgsoap++.so
%{_libdir}/libgsoapck.so
%{_libdir}/libgsoapck++.so
%{_libdir}/libgsoapssl.so
%{_libdir}/libgsoapssl++.so
%{_libdir}/pkgconfig/*.pc

%files source
%{_prefix}/src/%{name}

%files doc
%license LICENSE.txt
%doc NOTES.txt README.txt changelog.md factsheet.pdf license.pdf %name/doc


%changelog
* Sat Dec 21 2024 pterjan <pterjan> 2.8.104-5.mga10
+ Revision: 2127590
- Rebuild for patchN deprecation

* Thu Mar 17 2022 umeabot <umeabot> 2.8.104-4.mga9
+ Revision: 1797155
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 2.8.104-3.mga9
+ Revision: 1747800
- rebuild for openssl 3.0.0

* Mon Jun 07 2021 daviddavid <daviddavid> 2.8.104-2.mga9
+ Revision: 1730065
- backport upstream fixes for CVE-2020-1357[4-8] (mga#29015)

* Sun Jul 12 2020 daviddavid <daviddavid> 2.8.104-1.mga8
+ Revision: 1605455
- new version: 2.8.104
- fix library pkg name

* Tue Apr 28 2020 joequant <joequant> 2.8.93-4.mga8
+ Revision: 1572895
- add requires for gsoap-devel

* Tue Apr 28 2020 joequant <joequant> 2.8.93-3.mga8
+ Revision: 1572600
- convert to use shared libraries

* Mon Feb 17 2020 umeabot <umeabot> 2.8.93-2.mga8
+ Revision: 1537221
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Oct 27 2019 daviddavid <daviddavid> 2.8.93-1.mga8
+ Revision: 1456011
- new version: 2.8.93

* Tue Sep 03 2019 daviddavid <daviddavid> 2.8.91-1.mga8
+ Revision: 1436521
- new version: 2.8.91

* Sat Jul 20 2019 daviddavid <daviddavid> 2.8.87-1.mga8
+ Revision: 1423139
- new version: 2.8.87

* Sun Sep 23 2018 umeabot <umeabot> 2.8.67-2.mga7
+ Revision: 1298092
- Mageia 7 Mass Rebuild

* Thu Jun 21 2018 wally <wally> 2.8.67-1.mga7
+ Revision: 1238487
- new version 2.8.67

* Sun Apr 29 2018 anaselli <anaselli> 2.8.66-1.mga7
+ Revision: 1223616
- new version 2.8.66

* Thu Aug 03 2017 guillomovitch <guillomovitch> 2.8.49-2.mga7
+ Revision: 1134279
- rebuild for latest openssl

* Fri Jul 21 2017 anaselli <anaselli> 2.8.49-1.mga7
+ Revision: 1126265
- new version 2.8.49

* Fri Aug 12 2016 anaselli <anaselli> 2.8.33-1.mga6
+ Revision: 1046040
- new gsoap 2.8.33

* Mon Apr 11 2016 anaselli <anaselli> 2.8.30-1.mga6
+ Revision: 1000242
- new version

* Wed Mar 02 2016 umeabot <umeabot> 2.8.23-3.mga6
+ Revision: 983444
- Rebuild for openssl

* Thu Feb 11 2016 umeabot <umeabot> 2.8.23-2.mga6
+ Revision: 954198
- Mageia 6 Mass Rebuild

* Thu Oct 01 2015 anaselli <anaselli> 2.8.23-1.mga6
+ Revision: 885515
- New version 2.8.23

* Wed Oct 15 2014 umeabot <umeabot> 2.8.18-3.mga5
+ Revision: 741104
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.8.18-2.mga5
+ Revision: 679965
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 anaselli <anaselli> 2.8.18-1.mga5
+ Revision: 674321
- new version 2.8.18

* Fri Apr 18 2014 anaselli <anaselli> 2.8.17-1.mga5
+ Revision: 616873
- new version 2.8.17

* Mon Oct 21 2013 umeabot <umeabot> 2.8.16-2.mga4
+ Revision: 537938
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 anaselli <anaselli> 2.8.16-1.mga4
+ Revision: 488056
- New version 2.8.16

* Wed Jun 26 2013 anaselli <anaselli> 2.8.15-1.mga4
+ Revision: 447312
- New bug fixing version 1.8.15

* Thu Jan 17 2013 anaselli <anaselli> 2.8.12-2.mga3
+ Revision: 389214
- applied barjac changes, to remove other binary files
- removed useless binaries into source package
- new GPLv2 version 2.8.12
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 05 2013 cjw <cjw> 2.7.17-2.mga3
+ Revision: 339120
- patch2: fix build with automake 1.13
- remove pre-built binaries from unpacked source tree

* Tue Jan 18 2011 ahmad <ahmad> 2.7.17-1.mga1
+ Revision: 21919
- imported package gsoap

